@@ -71,7 +71,7 @@ class Obj:
 
     data: str
     """
-    DATA - The compiled code of a contract OR the hash of the invoked method signature and encoded parameters. For details see etdereum Contract ABI.
+    DATA - The compiled code of a contract OR the hash of the invoked method signature and encoded parameters. For details see etherdata Contract ABI.
     """
 
     nonce: Optional[str]
@@ -505,8 +505,10 @@ class JsonRpcMethods:
 
     def protocal_version(self, ) -> str:
         """
-        Returns the current etdereum protocol version
-        :return version: The current etdereum protocol version
+        Returns the current etherdata protocol version
+        #### Returns
+
+        version: The current etherdata protocol version
         """
         json_data = {
             "method": "eth_protocalVersion",
@@ -520,7 +522,9 @@ class JsonRpcMethods:
     def block_number(self, ) -> str:
         """
         Returns the current block number
-        :return blockNumber: The current blockNumber
+        #### Returns
+
+        blockNumber: The current blockNumber
         """
         json_data = {
             "method": "eth_blockNumber",
@@ -534,8 +538,10 @@ class JsonRpcMethods:
     def syncing(self, ) -> SyncingResponse:
         """
         Returns an object with data about the sync status or false
-        :return syncObject: return this ONLY when syncing
-        :return syncStatus: return this ONLY when not syncing
+        #### Returns #SyncingResponse
+
+        syncObject: return this ONLY when syncing
+        syncStatus: return this ONLY when not syncing
         """
         json_data = {
             "method": "eth_syncing",
@@ -549,7 +555,9 @@ class JsonRpcMethods:
     def coinbase(self, ) -> Any:
         """
         Returns the client coinbase address
-        :return coinbase: The client coinbase address
+        #### Returns
+
+        coinbase: The client coinbase address
         """
         json_data = {
             "method": "eth_coinbase",
@@ -563,7 +571,9 @@ class JsonRpcMethods:
     def mining(self, ) -> bool:
         """
         Returns true if client is actively mining new blocks
-        :return isMining: True if client is actively mining new blocks.
+        #### Returns
+
+        isMining: True if client is actively mining new blocks.
         """
         json_data = {
             "method": "eth_mining",
@@ -577,7 +587,9 @@ class JsonRpcMethods:
     def hashrate(self, ) -> Any:
         """
         Returns the number of hashes per second that the node is mining with
-        :return hashrate: The number of hashes per second that the node is mining with
+        #### Returns
+
+        hashrate: The number of hashes per second that the node is mining with
         """
         json_data = {
             "method": "eth_hashrate",
@@ -591,7 +603,9 @@ class JsonRpcMethods:
     def gas_price(self, ) -> Any:
         """
         Returns the current price per gas in wei
-        :return gasPrice: The current price per gas in wei (8049999872 Wei in the example)
+        #### Returns
+
+        gasPrice: The current price per gas in wei (8049999872 Wei in the example)
         """
         json_data = {
             "method": "eth_gasPrice",
@@ -605,7 +619,9 @@ class JsonRpcMethods:
     def accounts(self, ) -> List[Any]:
         """
         Returns a list of addresses owned by client
-        :return addressAccount: The array of accouts
+        #### Returns
+
+        addressAccount: The array of accouts
         """
         json_data = {
             "method": "eth_accounts",
@@ -616,12 +632,16 @@ class JsonRpcMethods:
         response = requests.post(self.url, json=to_dict(json_data))
         return response.json()["result"]
 
-    def get_balance(self, address_str_tag_str) -> float:
+    def get_balance(self, address: str, tag: str) -> float:
         """
         Returns the balance of the account of given address
-        :param address: DATA, 20 Bytes - address to check for balance
-        :param tag: QUANTITY_TAG - integer block number, or the string "latest", "earliest" or "pending", see the default block parameter
-        :return balance: QUANTITY - integer of the current balance in wei.
+        #### Arguments
+
+        address: DATA, 20 Bytes - address to check for balance
+        tag: QUANTITY_TAG - integer block number, or the string "latest", "earliest" or "pending", see the default block parameter
+        #### Returns
+
+        balance: QUANTITY - integer of the current balance in wei.
         """
         json_data = {
             "method": "eth_getBalance",
@@ -632,13 +652,17 @@ class JsonRpcMethods:
         response = requests.post(self.url, json=to_dict(json_data))
         return response.json()["result"]
 
-    def get_storage_at(self, address_any_position_any_tag_str) -> Any:
+    def get_storage_at(self, address: any, position: any, tag: str) -> Any:
         """
         Returns the value from a storage position at a given address
-        :param address: DATA, 20 Bytes - address of the storage.
-        :param position: The integer of the position in the storage.
-        :param tag: QUANTITY_TAG - integer block number, or the string "latest", "earliest" or "pending", see the default block parameter
-        :return valur: The value at this storage position.
+        #### Arguments
+
+        address: DATA, 20 Bytes - address of the storage.
+        position: The integer of the position in the storage.
+        tag: QUANTITY_TAG - integer block number, or the string "latest", "earliest" or "pending", see the default block parameter
+        #### Returns
+
+        valur: The value at this storage position.
         """
         json_data = {
             "method": "eth_getStorageAt",
@@ -649,12 +673,16 @@ class JsonRpcMethods:
         response = requests.post(self.url, json=to_dict(json_data))
         return response.json()["result"]
 
-    def get_transaction_count(self, address_any_state_str) -> float:
+    def get_transaction_count(self, address: any, state: str) -> float:
         """
         Returns the number of transactions sent from an address
-        :param address: The address.
-        :param state: QUANTITY_TAG - integer block number, or the string "latest", "earliest" or "pending", see the default block parameter
-        :return number: The number of transactions send from this address.
+        #### Arguments
+
+        address: The address.
+        state: QUANTITY_TAG - integer block number, or the string "latest", "earliest" or "pending", see the default block parameter
+        #### Returns
+
+        number: The number of transactions send from this address.
         """
         json_data = {
             "method": "eth_getTransactionCount",
@@ -666,12 +694,16 @@ class JsonRpcMethods:
         return response.json()["result"]
 
     def get_transaction_count_by_hash(
-            self, data_str_q_u_a_n_t_i_t_y__t_a_g_str) -> str:
+            self, data: str, q_u_a_n_t_i_t_y__t_a_g: str) -> str:
         """
         Returns the number of transactions in a block from a block matching the given block hash
-        :param data: 20 Bytes - The address
-        :param qUANTITY_TAG: integer block number, or the string "latest", "earliest" or "pending", see the default block parameter
-        :return quantity: The integer of the number of transactions send from this address.
+        #### Arguments
+
+        data: 20 Bytes - The address
+        qUANTITY_TAG: integer block number, or the string "latest", "earliest" or "pending", see the default block parameter
+        #### Returns
+
+        quantity: The integer of the number of transactions send from this address.
         """
         json_data = {
             "method": "eth_getTransactionCountByHash",
@@ -682,11 +714,15 @@ class JsonRpcMethods:
         response = requests.post(self.url, json=to_dict(json_data))
         return response.json()["result"]
 
-    def get_block_transaction_count_by_hash(self, data_str) -> str:
+    def get_block_transaction_count_by_hash(self, d_a_t_a: str) -> str:
         """
         Returns the number of transactions in a block from a block matching the given block hash
-        :param data: 32 Bytes - The hash of a block
-        :return quantity: The integer of the number of transactions in this block.
+        #### Arguments
+
+        data: 32 Bytes - The hash of a block
+        #### Returns
+
+        quantity: The integer of the number of transactions in this block.
         """
         json_data = {
             "method": "eth_getBlockTransactionCountByHash",
@@ -698,11 +734,15 @@ class JsonRpcMethods:
         return response.json()["result"]
 
     def get_block_transaction_count_by_number(
-            self, q_u_a_n_t_i_t_y__t_a_g_str) -> str:
+            self, q_u_a_n_t_i_t_y__t_a_g: str) -> str:
         """
         Returns the number of transactions in a block matching the given block number
-        :param qUANTITY_TAG: The integer of a block number, or the string "earliest", "latest" or "pending", see the default block parameter
-        :return quantity: The integer of the number of transactions in this block.
+        #### Arguments
+
+        qUANTITY_TAG: The integer of a block number, or the string "earliest", "latest" or "pending", see the default block parameter
+        #### Returns
+
+        quantity: The integer of the number of transactions in this block.
         """
         json_data = {
             "method": "eth_getBlockTransactionCountByNumber",
@@ -713,11 +753,15 @@ class JsonRpcMethods:
         response = requests.post(self.url, json=to_dict(json_data))
         return response.json()["result"]
 
-    def get_uncle_count_by_block_hash(self, data_str) -> str:
+    def get_uncle_count_by_block_hash(self, d_a_t_a: str) -> str:
         """
         Returns the number of uncles in a block from a block matching the given block hash
-        :param data: 32 Bytes - The hash of a block
-        :return qUANTITY_TAG: The integer of the number of uncles in this block.
+        #### Arguments
+
+        data: 32 Bytes - The hash of a block
+        #### Returns
+
+        qUANTITY_TAG: The integer of the number of uncles in this block.
         """
         json_data = {
             "method": "eth_getUncleCountByBlockHash",
@@ -729,11 +773,15 @@ class JsonRpcMethods:
         return response.json()["result"]
 
     def get_uncle_count_by_block_number(
-            self, q_u_a_n_t_i_t_y__t_a_g_str) -> str:
+            self, q_u_a_n_t_i_t_y__t_a_g: str) -> str:
         """
         Returns the number of uncles in a block from a block matching the given block number
-        :param qUANTITY_TAG: The integer of a block number, or the string “latest”, “earliest” or “pending”, see the default block parameter
-        :return quantity: The integer of the number of uncles in this block.
+        #### Arguments
+
+        qUANTITY_TAG: The integer of a block number, or the string “latest”, “earliest” or “pending”, see the default block parameter
+        #### Returns
+
+        quantity: The integer of the number of uncles in this block.
         """
         json_data = {
             "method": "eth_getUncleCountByBlockNumber",
@@ -744,12 +792,16 @@ class JsonRpcMethods:
         response = requests.post(self.url, json=to_dict(json_data))
         return response.json()["result"]
 
-    def get_code(self, data_str_q_u_a_n_t_i_t_y__t_a_g_str) -> str:
+    def get_code(self, d_a_t_a: str, q_u_a_n_t_i_t_y__t_a_g: str) -> str:
         """
         Returns code at a given address
-        :param data: 20 Byter - The address
-        :param qUANTITY_TAG: The integer block number, or the string "latest", "earliest" or "pending", see the default block parameter
-        :return data: The code from the given address.
+        #### Arguments
+
+        data: 20 Byter - The address
+        qUANTITY_TAG: The integer block number, or the string "latest", "earliest" or "pending", see the default block parameter
+        #### Returns
+
+        data: The code from the given address.
         """
         json_data = {
             "method": "eth_code",
@@ -760,19 +812,23 @@ class JsonRpcMethods:
         response = requests.post(self.url, json=to_dict(json_data))
         return response.json()["result"]
 
-    def sign(self, a_str_b_str) -> str:
+    def sign(self, a: str, b: str) -> str:
         """
-        The sign method calculates an etdereum specific signature with sign(keccak256("\x19etdereum Signed Message:\n" + len(message) + message)))
+        The sign method calculates an etherdata specific signature with sign(keccak256("\x19etherdata Signed Message:\n" + len(message) + message)))
 
-        By adding a prefix to the message makes the calculated signature recognisable as an etdereum specific signature
+        By adding a prefix to the message makes the calculated signature recognisable as an etherdata specific signature
          This prevents misuse where a malicious DApp can sign arbitrary data (e
         g
          transaction) and use the signature to impersonate the victim
 
         Note the address to sign with must be unlocked
-        :param a: 20 Bytes - The address
-        :param b: N Bytes - The message to sign
-        :return value: The signature
+        #### Arguments
+
+        a: 20 Bytes - The address
+        b: N Bytes - The message to sign
+        #### Returns
+
+        value: The signature
         """
         json_data = {
             "method": "eth_sign",
@@ -783,11 +839,15 @@ class JsonRpcMethods:
         response = requests.post(self.url, json=to_dict(json_data))
         return response.json()["result"]
 
-    def sign_transaction(self, obj_obj) -> str:
+    def sign_transaction(self, obj: obj) -> str:
         """
         Signs a transaction that can be submitted to the network at a later time using with eth_sendRawTransaction
-        :param obj: The transaction object
-        :return data: The signed transaction object.
+        #### Arguments
+
+        obj: The transaction object
+        #### Returns
+
+        data: The signed transaction object.
         """
         json_data = {
             "method": "eth_signTransaction",
@@ -798,11 +858,15 @@ class JsonRpcMethods:
         response = requests.post(self.url, json=to_dict(json_data))
         return response.json()["result"]
 
-    def send_transcation(self, obj_obj) -> str:
+    def send_transcation(self, obj: obj) -> str:
         """
         Creates new message call transaction or a contract creation, if the data field contains code
-        :param obj: The transaction object
-        :return data: 32 Bytes - the transaction hash, or the zero hash if the transaction is not yet available. Use eth_getTransactionReceipt to get the contract address, after the transaction was mined, when you created a contract.
+        #### Arguments
+
+        obj: The transaction object
+        #### Returns
+
+        data: 32 Bytes - the transaction hash, or the zero hash if the transaction is not yet available. Use eth_getTransactionReceipt to get the contract address, after the transaction was mined, when you created a contract.
         """
         json_data = {
             "method": "eth_sendTranscation",
@@ -813,11 +877,15 @@ class JsonRpcMethods:
         response = requests.post(self.url, json=to_dict(json_data))
         return response.json()["result"]
 
-    def send_raw_transaction(self, data_str) -> str:
+    def send_raw_transaction(self, d_a_t_a: str) -> str:
         """
         Creates new message call transaction or a contract creation for signed transactions
-        :param data: The signed transaction data.
-        :return data: 32 Bytes - the transaction hash, or the zero hash if the transaction is not yet available. Use eth_getTransactionReceipt to get the contract address, after the transaction was mined, when you created a contract.
+        #### Arguments
+
+        data: The signed transaction data.
+        #### Returns
+
+        data: 32 Bytes - the transaction hash, or the zero hash if the transaction is not yet available. Use eth_getTransactionReceipt to get the contract address, after the transaction was mined, when you created a contract.
         """
         json_data = {
             "method": "eth_sendRawTransaction",
@@ -828,12 +896,16 @@ class JsonRpcMethods:
         response = requests.post(self.url, json=to_dict(json_data))
         return response.json()["result"]
 
-    def call(self, obj_obj_q_u_a_n_t_i_t_y__t_a_g_str) -> str:
+    def call(self, obj: obj, q_u_a_n_t_i_t_y__t_a_g: str) -> str:
         """
         Executes a new message call immediately without creating a transaction on the block chain
-        :param obj: The transaction object
-        :param qUANTITY_TAG: The integer block number, or the string "latest", "earliest" or "pending", see the default block parameter.
-        :return data: The return value of executed contract.
+        #### Arguments
+
+        obj: The transaction object
+        qUANTITY_TAG: The integer block number, or the string "latest", "earliest" or "pending", see the default block parameter.
+        #### Returns
+
+        data: The return value of executed contract.
         """
         json_data = {
             "method": "eth_call",
@@ -844,14 +916,18 @@ class JsonRpcMethods:
         response = requests.post(self.url, json=to_dict(json_data))
         return response.json()["result"]
 
-    def estimate_gas(self, obj_obj_q_u_a_n_t_i_t_y__t_a_g_str) -> str:
+    def estimate_gas(self, obj: obj, q_u_a_n_t_i_t_y__t_a_g: str) -> str:
         """
         Generates and returns an estimate of how much gas is necessary to allow the transaction to complete
          The transaction will not be added to the blockchain
          Note that the estimate may be significantly more than the amount of gas actually used by the transaction, for a variety of reasons including EVM mechanics and node performance
-        :param obj: The transaction object
-        :param qUANTITY_TAG: The integer block number, or the string "latest", "earliest" or "pending", see the default block parameter.
-        :return quantity: The amount of gas used.
+        #### Arguments
+
+        obj: The transaction object
+        qUANTITY_TAG: The integer block number, or the string "latest", "earliest" or "pending", see the default block parameter.
+        #### Returns
+
+        quantity: The amount of gas used.
         """
         json_data = {
             "method": "eth_estimateGas",
@@ -864,12 +940,17 @@ class JsonRpcMethods:
 
     def get_block_by_hash(
             self,
-            data_str_bool_field_bool) -> GetBlockByHashResponseObj:
+            d_a_t_a: str,
+            bool: bool) -> GetBlockByHashResponseObj:
         """
         Returns information about a block by hash
-        :param data: 32 Bytes - Hash of a block.
-        :param bool: If true it returns the full transaction objects, if false only the hashes of the transactions.
-        :return obj: A block object, or null when no block was found
+        #### Arguments
+
+        data: 32 Bytes - Hash of a block.
+        bool: If true it returns the full transaction objects, if false only the hashes of the transactions.
+        #### Returns #GetBlockByHashResponseObj
+
+        obj: A block object, or null when no block was found
         """
         json_data = {
             "method": "eth_getBlockByHash",
@@ -882,12 +963,17 @@ class JsonRpcMethods:
 
     def get_block_by_number(
             self,
-            q_u_a_n_t_i_t_y__t_a_g_str_bool_field_bool) -> GetBlockByNumberResponseObj:
+            q_u_a_n_t_i_t_y__t_a_g: str,
+            bool: bool) -> GetBlockByNumberResponseObj:
         """
         Returns information about a block by block number
-        :param qUANTITY_TAG: The integer of a block number, or the string "earliest", "latest" or "pending", as in the default block parameter.
-        :param bool: If true it returns the full transaction objects, if false only the hashes of the transactions.
-        :return obj: A block object, or null when no block was found
+        #### Arguments
+
+        qUANTITY_TAG: The integer of a block number, or the string "earliest", "latest" or "pending", as in the default block parameter.
+        bool: If true it returns the full transaction objects, if false only the hashes of the transactions.
+        #### Returns #GetBlockByNumberResponseObj
+
+        obj: A block object, or null when no block was found
         """
         json_data = {
             "method": "eth_getBlockByNumber",
@@ -899,11 +985,15 @@ class JsonRpcMethods:
         return GetBlockByNumberResponseObj.from_dict(response.json()["result"])
 
     def get_transaction_by_hash(
-            self, data_str) -> GetTransactionByHashResponseObj:
+            self, d_a_t_a: str) -> GetTransactionByHashResponseObj:
         """
         Returns the information about a transaction requested by transaction hash
-        :param data: 32 Bytes - hash of a transaction
-        :return obj: A transaction object, or null when no transaction was found
+        #### Arguments
+
+        data: 32 Bytes - hash of a transaction
+        #### Returns #GetTransactionByHashResponseObj
+
+        obj: A transaction object, or null when no transaction was found
         """
         json_data = {
             "method": "eth_getTransactionByHash",
@@ -916,12 +1006,18 @@ class JsonRpcMethods:
             response.json()["result"])
 
     def get_transaction_by_hash_and_index(
-            self, data_str_quantity_str) -> GetTransactionByHashAndIndexResponseObj:
+            self,
+            d_a_t_a: str,
+            q_u_a_n_t_i_t_y: str) -> GetTransactionByHashAndIndexResponseObj:
         """
         Returns information about a transaction by block hash and transaction index position
-        :param data: 32 Bytes - hash of a block.
-        :param quantity: The integer of the transaction index position.
-        :return obj: See eth_getTransactionByHash
+        #### Arguments
+
+        data: 32 Bytes - hash of a block.
+        quantity: The integer of the transaction index position.
+        #### Returns #GetTransactionByHashAndIndexResponseObj
+
+        obj: See eth_getTransactionByHash
         """
         json_data = {
             "method": "eth_getTransactionByHashAndIndex",
@@ -935,12 +1031,17 @@ class JsonRpcMethods:
 
     def get_transaction_by_block_number_and_index(
             self,
-            q_u_a_n_t_i_t_y__t_a_g_str_quantity_str) -> GetTransactionByBlockNumberAndIndexResponseObj:
+            q_u_a_n_t_i_t_y__t_a_g: str,
+            q_u_a_n_t_i_t_y: str) -> GetTransactionByBlockNumberAndIndexResponseObj:
         """
         Returns information about a transaction by block number and transaction index position
-        :param qUANTITY_TAG: a block number, or the string "earliest", "latest" or "pending", as in the default block parameter.
-        :param quantity: The transaction index position.
-        :return obj: See eth_getTransactionByHash
+        #### Arguments
+
+        qUANTITY_TAG: a block number, or the string "earliest", "latest" or "pending", as in the default block parameter.
+        quantity: The transaction index position.
+        #### Returns #GetTransactionByBlockNumberAndIndexResponseObj
+
+        obj: See eth_getTransactionByHash
         """
         json_data = {
             "method": "eth_getTransactionByBlockNumberAndIndex",
@@ -953,12 +1054,16 @@ class JsonRpcMethods:
                                                                         "result"])
 
     def get_transaction_receipt(
-            self, data_str) -> GetTransactionReceiptResponseObj:
+            self, d_a_t_a: str) -> GetTransactionReceiptResponseObj:
         """
         Returns the receipt of a transaction by transaction hash
          Note That the receipt is not available for pending transactions
-        :param data: 32 Bytes - hash of a transaction
-        :return obj: A transaction receipt object, or null when no receipt was found
+        #### Arguments
+
+        data: 32 Bytes - hash of a transaction
+        #### Returns #GetTransactionReceiptResponseObj
+
+        obj: A transaction receipt object, or null when no receipt was found
         """
         json_data = {
             "method": "eth_getTransactionReceipt",
@@ -971,12 +1076,18 @@ class JsonRpcMethods:
             response.json()["result"])
 
     def get_uncle_by_block_hash_and_index(
-            self, data_str_quantity_str) -> GetUncleByBlockHashAndIndexResponseObj:
+            self,
+            d_a_t_a: str,
+            q_u_a_n_t_i_t_y: str) -> GetUncleByBlockHashAndIndexResponseObj:
         """
         eturns information about a uncle of a block by hash and uncle index position
-        :param data: 32 Bytes - The hash of a block.
-        :param quantity: The uncle’s index position.
-        :return obj: See eth_getTransactionByHash Note - An uncle doesn’t contain individual transactions.
+        #### Arguments
+
+        data: 32 Bytes - The hash of a block.
+        quantity: The uncle’s index position.
+        #### Returns #GetUncleByBlockHashAndIndexResponseObj
+
+        obj: See eth_getTransactionByHash Note - An uncle doesn’t contain individual transactions.
         """
         json_data = {
             "method": "eth_getUncleByBlockHashAndIndex",
@@ -990,12 +1101,17 @@ class JsonRpcMethods:
 
     def get_uncle_by_block_number_and_index(
             self,
-            q_u_a_n_t_i_t_y__t_a_g_str_quantity_str) -> GetUncleByBlockNumberAndIndexResponseObj:
+            q_u_a_n_t_i_t_y__t_a_g: str,
+            q_u_a_n_t_i_t_y: str) -> GetUncleByBlockNumberAndIndexResponseObj:
         """
         Returns information about a uncle of a block by number and uncle index position
-        :param qUANTITY_TAG: a block number, or the string "earliest", "latest" or "pending", as in the default block parameter.
-        :param quantity: the uncle’s index position.
-        :return obj: See eth_getTransactionByHash Note - An uncle doesn’t contain individual transactions.
+        #### Arguments
+
+        qUANTITY_TAG: a block number, or the string "earliest", "latest" or "pending", as in the default block parameter.
+        quantity: the uncle’s index position.
+        #### Returns #GetUncleByBlockNumberAndIndexResponseObj
+
+        obj: See eth_getTransactionByHash Note - An uncle doesn’t contain individual transactions.
         """
         json_data = {
             "method": "eth_getUncleByBlockNumberAndIndex",
@@ -1010,7 +1126,9 @@ class JsonRpcMethods:
     def get_compliers(self, ) -> List[str]:
         """
         Returns a list of available compilers in the client
-        :return array: Array of available compilers.
+        #### Returns
+
+        array: Array of available compilers.
         """
         json_data = {
             "method": "eth_getCompliers",
@@ -1021,11 +1139,15 @@ class JsonRpcMethods:
         response = requests.post(self.url, json=to_dict(json_data))
         return response.json()["result"]
 
-    def compile_solidity(self, string_str) -> str:
+    def compile_solidity(self, string: str) -> str:
         """
         Returns compiled solidity code
-        :param string: The source code.
-        :return data: The compiled source code.
+        #### Arguments
+
+        string: The source code.
+        #### Returns
+
+        data: The compiled source code.
         """
         json_data = {
             "method": "eth_compileSolidity",
@@ -1036,11 +1158,15 @@ class JsonRpcMethods:
         response = requests.post(self.url, json=to_dict(json_data))
         return response.json()["result"]
 
-    def complpie_l_l_l(self, string_str) -> str:
+    def complpie_l_l_l(self, string: str) -> str:
         """
         Returns compiled LLL code
-        :param string: The source code.
-        :return data: The compiled source code.
+        #### Arguments
+
+        string: The source code.
+        #### Returns
+
+        data: The compiled source code.
         """
         json_data = {
             "method": "eth_complpieLLL",
@@ -1051,11 +1177,15 @@ class JsonRpcMethods:
         response = requests.post(self.url, json=to_dict(json_data))
         return response.json()["result"]
 
-    def complie_serpent(self, string_str) -> str:
+    def complie_serpent(self, string: str) -> str:
         """
         Returns compiled serpent code
-        :param string: The source code.
-        :return data: The compiled source code.
+        #### Arguments
+
+        string: The source code.
+        #### Returns
+
+        data: The compiled source code.
         """
         json_data = {
             "method": "eth_complieSerpent",
@@ -1066,7 +1196,7 @@ class JsonRpcMethods:
         response = requests.post(self.url, json=to_dict(json_data))
         return response.json()["result"]
 
-    def new_filter(self, obj_obj) -> str:
+    def new_filter(self, obj: obj) -> str:
         """
         Creates a filter object, based on filter options, to notify when the state changes (logs)
          To check if the state has changed, call eth_getFilterChanges
@@ -1074,8 +1204,12 @@ class JsonRpcMethods:
         A note on specifying topic filters Topics are order-dependent
          A transaction with a log with topics [A, B] will be matched by the following topic filters
         -[] “anything” -[A] “A in first position (and anything after)” -[null, B] “anything in first position AND B in second position (and anything after)” -[A, B] “A in first position AND B in second position (and anything after)” -[[A, B], [A, B]] “(A OR B) in first position AND (A OR B) in second position (and anything after)”
-        :param obj: The filter options
-        :return quantity: A filter id.
+        #### Arguments
+
+        obj: The filter options
+        #### Returns
+
+        quantity: A filter id.
         """
         json_data = {
             "method": "eth_newFilter",
@@ -1090,7 +1224,9 @@ class JsonRpcMethods:
         """
         Creates a filter in the node, to notify when a new block arrives
          To check if the state has changed, call eth_getFilterChanges
-        :return quantity: A filter id.
+        #### Returns
+
+        quantity: A filter id.
         """
         json_data = {
             "method": "eth_newBlockFilter",
@@ -1105,7 +1241,9 @@ class JsonRpcMethods:
         """
         Creates a filter in the node, to notify when new pending transactions arrive
          To check if the state has changed, call eth_getFilterChanges
-        :return quantity: A filter id.
+        #### Returns
+
+        quantity: A filter id.
         """
         json_data = {
             "method": "eth_newPendingTransactionFilter",
@@ -1116,14 +1254,18 @@ class JsonRpcMethods:
         response = requests.post(self.url, json=to_dict(json_data))
         return response.json()["result"]
 
-    def uninstall_filter(self, quantity_str) -> bool:
+    def uninstall_filter(self, q_u_a_n_t_i_t_y: str) -> bool:
         """
         Uninstalls a filter with given id
          Should always be called when watch is no longer needed
          Additonally Filters timeout when they aren’t requested with eth_getFilterChanges
          for a period of time
-        :param quantity: The filter id.
-        :return bool: true if the filter was successfully uninstalled, otherwise false.
+        #### Arguments
+
+        quantity: The filter id.
+        #### Returns
+
+        bool: true if the filter was successfully uninstalled, otherwise false.
         """
         json_data = {
             "method": "eth_uninstallFilter",
@@ -1134,11 +1276,15 @@ class JsonRpcMethods:
         response = requests.post(self.url, json=to_dict(json_data))
         return response.json()["result"]
 
-    def get_filter_changes(self, quantity_str) -> List[Array]:
+    def get_filter_changes(self, q_u_a_n_t_i_t_y: str) -> List[Array]:
         """
         Polling method for a filter, which returns an array of logs which occurred since last poll
-        :param quantity: The filter id.
-        :return array: Array of log objects, or an empty array if nothing has changed since last poll. For filters created with eth_newBlockFilter the return are block hashes (DATA, 32 Bytes), e.g. ["0x3454645634534..."]. For filters created with eth_newPendingTransactionFilter the return are transaction hashes (DATA, 32 Bytes), e.g. ["0x6345343454645..."].
+        #### Arguments
+
+        quantity: The filter id.
+        #### Returns #List[Array]
+
+        array: Array of log objects, or an empty array if nothing has changed since last poll. For filters created with eth_newBlockFilter the return are block hashes (DATA, 32 Bytes), e.g. ["0x3454645634534..."]. For filters created with eth_newPendingTransactionFilter the return are transaction hashes (DATA, 32 Bytes), e.g. ["0x6345343454645..."].
         """
         json_data = {
             "method": "eth_getFilterChanges",
@@ -1149,11 +1295,15 @@ class JsonRpcMethods:
         response = requests.post(self.url, json=to_dict(json_data))
         return Array.schema().load(response.json()["result"], many=True)
 
-    def get_filter_logs(self, quantity_str) -> List[Any]:
+    def get_filter_logs(self, q_u_a_n_t_i_t_y: str) -> List[Any]:
         """
         Returns an array of all logs matching filter with given id
-        :param quantity: The filter id.
-        :return array: See eth_getFilterChanges.
+        #### Arguments
+
+        quantity: The filter id.
+        #### Returns
+
+        array: See eth_getFilterChanges.
         """
         json_data = {
             "method": "eth_getFilterLogs",
@@ -1164,11 +1314,15 @@ class JsonRpcMethods:
         response = requests.post(self.url, json=to_dict(json_data))
         return response.json()["result"]
 
-    def get_logs(self, obj_obj) -> List[Any]:
+    def get_logs(self, obj: obj) -> List[Any]:
         """
         Returns an array of all logs matching a given filter object
-        :param obj: The filter options
-        :return array: See eth_getFilterChanges.
+        #### Arguments
+
+        obj: The filter options
+        #### Returns
+
+        array: See eth_getFilterChanges.
         """
         json_data = {
             "method": "eth_getLogs",
@@ -1182,7 +1336,9 @@ class JsonRpcMethods:
     def get_work(self, ) -> List[str]:
         """
         Returns the hash of the current block, the seedHash, and the boundary condition to be met (“target”)
-        :return array: Array with the following properties -DATA, 32 Bytes - current block header pow-hash -DATA, 32 Bytes - the seed hash used for the DAG. -DATA, 32 Bytes - the boundary condition (“target”), 2^256  difficulty.
+        #### Returns
+
+        array: Array with the following properties -DATA, 32 Bytes - current block header pow-hash -DATA, 32 Bytes - the seed hash used for the DAG. -DATA, 32 Bytes - the boundary condition (“target”), 2^256  difficulty.
         """
         json_data = {
             "method": "eth_getWork",
@@ -1193,13 +1349,17 @@ class JsonRpcMethods:
         response = requests.post(self.url, json=to_dict(json_data))
         return response.json()["result"]
 
-    def submit_work(self, a_str_b_str_c_str) -> bool:
+    def submit_work(self, a: str, b: str, c: str) -> bool:
         """
         Used for submitting a proof-of-work solution
-        :param a: 8 Bytes - The nonce found (64 bits)
-        :param b: 32 Bytes - The header’s pow-hash (256 bits)
-        :param c: 32 Bytes - The mix digest (256 bits)
-        :return bool: returns true if the provided solution is valid, otherwise false.
+        #### Arguments
+
+        a: 8 Bytes - The nonce found (64 bits)
+        b: 32 Bytes - The header’s pow-hash (256 bits)
+        c: 32 Bytes - The mix digest (256 bits)
+        #### Returns
+
+        bool: returns true if the provided solution is valid, otherwise false.
         """
         json_data = {
             "method": "eth_submitWork",
@@ -1210,12 +1370,16 @@ class JsonRpcMethods:
         response = requests.post(self.url, json=to_dict(json_data))
         return response.json()["result"]
 
-    def submit_hashrate(self, hashrate_str_id_str) -> bool:
+    def submit_hashrate(self, hashrate: str, i_d: str) -> bool:
         """
         Used for submitting mining hashrate
-        :param hashrate: A hexadecimal string representation (32 bytes) of the hash rate
-        :param id: String - A random hexadecimal(32 bytes) ID identifying the client
-        :return bool: Returns `true` if submitting went through succesfully and `false` otherwise.
+        #### Arguments
+
+        hashrate: A hexadecimal string representation (32 bytes) of the hash rate
+        id: String - A random hexadecimal(32 bytes) ID identifying the client
+        #### Returns
+
+        bool: Returns `true` if submitting went through succesfully and `false` otherwise.
         """
         json_data = {
             "method": "eth_submitHashrate",
