@@ -192,13 +192,18 @@ class RealTime:
 
     def create_subscription(
             self,
-            subscription_name_str_aaaaa_optional_any_) -> str:
+            subscription_name: str,
+            aaaaa: optional[any]) -> str:
         """
         Subscriptions are created with a regular RPC call with etd_subscribe as method and the subscription name as first parameter
          If successful it returns the subscription id
-        :param subscriptionName: The subscription name
-        :param aaaaa:
-        :return subscriptionID: The subscription ID
+        #### Arguments
+
+        subscriptionName: The subscription name
+        aaaaa:
+        #### Returns
+
+        subscriptionID: The subscription ID
         """
         json_data = {
             "method": "real-time_createSubscription",
@@ -209,12 +214,16 @@ class RealTime:
         response = requests.post(self.url, json=to_dict(json_data))
         return response.json()["result"]
 
-    def cancel_subscription(self, subscription_i_d_str) -> bool:
+    def cancel_subscription(self, subscription_i_d: str) -> bool:
         """
         Subscriptions are cancelled with a regular RPC call with etd_unsubscribe as method and the subscription id as first parameter
          It returns a bool indicating if the subscription was cancelled successful
-        :param subscriptionID: The subscription ID
-        :return cancelled: Indicating if the subscription was cancelled successful.
+        #### Arguments
+
+        subscriptionID: The subscription ID
+        #### Returns
+
+        cancelled: Indicating if the subscription was cancelled successful.
         """
         json_data = {
             "method": "real-time_cancelSubscription",
@@ -227,7 +236,7 @@ class RealTime:
 
     def supported_subscriptions(
             self,
-            subscription_object_subscription_object) -> SupportedSubscriptionsResponseOutputObject:
+            subscription_object: subscriptionobject) -> SupportedSubscriptionsResponseOutputObject:
         """
         newHeads -Fires a notification each time a new header is appended to the chain, including chain reorganizations
          Users can use the bloom filter to determine if the block contains logs that are interested to them
@@ -238,8 +247,12 @@ class RealTime:
          -In case of a chain reorganization previous sent logs that are on the old chain will be resend with the removed property set to true
          Logs from transactions that ended up in the new chain are emitted
          Therefore a subscription can emit logs for the same transaction multiple times
-        :param subscriptionObject: The object containing different opotional transcation fields
-        :return outputObject: The return Object of the function
+        #### Arguments
+
+        subscriptionObject: The object containing different opotional transcation fields
+        #### Returns #SupportedSubscriptionsResponseOutputObject
+
+        outputObject: The return Object of the function
         """
         json_data = {
             "method": "real-time_supportedSubscriptions",
@@ -255,8 +268,10 @@ class RealTime:
         """
         Returns the hash for all transactions that are added to the pending state and are signed with a key that is available in the node
          Tansaction that was previously part of the canonical chain isn’t part of the new canonical chain after a reogranization its again emitted
-        :return hash: The hash for all transactions
-        :return transcation: The transaction
+        #### Returns #NewPendingTransactionsResponse
+
+        hash: The hash for all transactions
+        transcation: The transaction
         """
         json_data = {
             "method": "real-time_newPendingTransactions",
@@ -272,8 +287,10 @@ class RealTime:
         """
         Indicates when the node starts or stops synchronizing
          The result can either be a boolean indicating that the synchronization has started (true), finished (false) or an object with various progress indicators
-        :return synchronized: Indicating that the synchronization has started (true) or finished (false)
-        :return status: An object with various progress indicators regarding the synchronization
+        #### Returns #SyncingResponse
+
+        synchronized: Indicating that the synchronization has started (true) or finished (false)
+        status: An object with various progress indicators regarding the synchronization
         """
         json_data = {
             "method": "real-time_syncing",
